@@ -494,6 +494,42 @@ public:
         m_indent--;
     }
 
+    void visitCompoundNamespace(CompoundNamespaceAst *node) override
+    {
+        printToken(node, QStringLiteral("compoundNamespace"));
+        if (node->compoundNamespaceStatementSequence)
+        {
+            const KDevPG::ListNode<CompoundNamespaceStatementAst*> *__it = node->compoundNamespaceStatementSequence->front(), *__end = __it;
+            do
+            {
+                printToken(__it->element, QStringLiteral("compoundNamespaceStatement"), QStringLiteral("compoundNamespaceStatement[]"));
+                __it = __it->next;
+            }
+            while (__it != __end);
+        }
+        ++m_indent;
+        DefaultVisitor::visitCompoundNamespace(node);
+        m_indent--;
+    }
+
+    void visitCompoundNamespaceStatement(CompoundNamespaceStatementAst *node) override
+    {
+        printToken(node, QStringLiteral("compoundNamespaceStatement"));
+        if (node->useNamespaceSequence)
+        {
+            const KDevPG::ListNode<InnerUseNamespaceAst*> *__it = node->useNamespaceSequence->front(), *__end = __it;
+            do
+            {
+                printToken(__it->element, QStringLiteral("innerUseNamespace"), QStringLiteral("useNamespace[]"));
+                __it = __it->next;
+            }
+            while (__it != __end);
+        }
+        ++m_indent;
+        DefaultVisitor::visitCompoundNamespaceStatement(node);
+        m_indent--;
+    }
+
     void visitCompoundVariable(CompoundVariableAst *node) override
     {
         printToken(node, QStringLiteral("compoundVariable"));
@@ -855,6 +891,25 @@ public:
         m_indent--;
     }
 
+    void visitInnerUseNamespace(InnerUseNamespaceAst *node) override
+    {
+        printToken(node, QStringLiteral("innerUseNamespace"));
+        if (node->namespaceNameSequence)
+        {
+            const KDevPG::ListNode<IdentifierAst*> *__it = node->namespaceNameSequence->front(), *__end = __it;
+            do
+            {
+                printToken(__it->element, QStringLiteral("identifier"), QStringLiteral("namespaceName[]"));
+                __it = __it->next;
+            }
+            while (__it != __end);
+        }
+        if (node->aliasIdentifier) printToken(node->aliasIdentifier, QStringLiteral("identifier"), QStringLiteral("aliasIdentifier"));
+        ++m_indent;
+        DefaultVisitor::visitInnerUseNamespace(node);
+        m_indent--;
+    }
+
     void visitInstantiationAccess(InstantiationAccessAst *node) override
     {
         printToken(node, QStringLiteral("instantiationAccess"));
@@ -1030,6 +1085,24 @@ public:
         m_indent--;
     }
 
+    void visitNamespacedIdentifierBeforeGroupedNamespace(NamespacedIdentifierBeforeGroupedNamespaceAst *node) override
+    {
+        printToken(node, QStringLiteral("namespacedIdentifierBeforeGroupedNamespace"));
+        if (node->namespaceNameSequence)
+        {
+            const KDevPG::ListNode<IdentifierAst*> *__it = node->namespaceNameSequence->front(), *__end = __it;
+            do
+            {
+                printToken(__it->element, QStringLiteral("identifier"), QStringLiteral("namespaceName[]"));
+                __it = __it->next;
+            }
+            while (__it != __end);
+        }
+        ++m_indent;
+        DefaultVisitor::visitNamespacedIdentifierBeforeGroupedNamespace(node);
+        m_indent--;
+    }
+
     void visitNewElseSingle(NewElseSingleAst *node) override
     {
         printToken(node, QStringLiteral("newElseSingle"));
@@ -1684,13 +1757,14 @@ public:
         m_indent--;
     }
 
-    void visitUseNamespace(UseNamespaceAst *node) override
+    void visitUseNamespaceOrUseGroupedNamespace(UseNamespaceOrUseGroupedNamespaceAst *node) override
     {
-        printToken(node, QStringLiteral("useNamespace"));
-        if (node->identifier) printToken(node->identifier, QStringLiteral("namespacedIdentifier"), QStringLiteral("identifier"));
+        printToken(node, QStringLiteral("useNamespaceOrUseGroupedNamespace"));
+        if (node->identifier) printToken(node->identifier, QStringLiteral("namespacedIdentifierBeforeGroupedNamespace"), QStringLiteral("identifier"));
         if (node->aliasIdentifier) printToken(node->aliasIdentifier, QStringLiteral("identifier"), QStringLiteral("aliasIdentifier"));
+        if (node->compoundNamespace) printToken(node->compoundNamespace, QStringLiteral("compoundNamespace"), QStringLiteral("compoundNamespace"));
         ++m_indent;
-        DefaultVisitor::visitUseNamespace(node);
+        DefaultVisitor::visitUseNamespaceOrUseGroupedNamespace(node);
         m_indent--;
     }
 
@@ -1699,10 +1773,10 @@ public:
         printToken(node, QStringLiteral("useStatement"));
         if (node->useNamespaceSequence)
         {
-            const KDevPG::ListNode<UseNamespaceAst*> *__it = node->useNamespaceSequence->front(), *__end = __it;
+            const KDevPG::ListNode<UseNamespaceOrUseGroupedNamespaceAst*> *__it = node->useNamespaceSequence->front(), *__end = __it;
             do
             {
-                printToken(__it->element, QStringLiteral("useNamespace"), QStringLiteral("useNamespace[]"));
+                printToken(__it->element, QStringLiteral("useNamespaceOrUseGroupedNamespace"), QStringLiteral("useNamespace[]"));
                 __it = __it->next;
             }
             while (__it != __end);
